/****************************************************************************
**
**  This file is part of GAP, a system for computational discrete algebra.
**
**  Copyright of GAP belongs to its developers, whose names are too numerous
**  to list here. Please refer to the COPYRIGHT file for details.
**
**  SPDX-License-Identifier: GPL-2.0-or-later
*/

#ifndef GAP_SYNTAXTREE_H
#define GAP_SYNTAXTREE_H

#include "common.h"

StructInitInfo * InitInfoSyntaxTree(void);

#endif    // GAP_SYNTAXTREE_H
